# pybmix: Bayesian Mixture Models in Python

A Python interface to [bayesmix](https://github.com/bayesmix-dev/bayesmix/)


## Installation

First, clone this repository with its submodules
```shell
git clone --recurse-submodule git@github.com:bayesmix-dev/pybmix.git
```
Ideally things should work by simply typing
```shell
pip3 install -e .
```
from the root folder of this repo.

## Getting Started

See our [tutorials](https://pybmix.readthedocs.io/en/docs/)!

## Contributing

Just get in touch with us (email in setup.cfg), open a PR or an Issue! 
